@@ -147,10 +147,14 @@ int main(int argc, char* argv[])
   Log::SetPath(logPath);
 
   THREAD_REGISTER();
-  Util::RegisterSignalHandlers();
+  Util::InitAppSignalHandlers();
 
   const std::string appVersion = Version::GetUiAppVersion();
-  LOG_INFO("starting %s", appVersion.c_str());
+  LOG_INFO("%s", appVersion.c_str());
+  std::string osArch = Util::GetOsArch();
+  LOG_INFO("%s", osArch.c_str());
+  std::string compiler = Util::GetCompiler();
+  LOG_INFO("%s", compiler.c_str());
 
   Util::InitTempDir();
   CacheUtil::InitCacheDir();
@@ -198,6 +202,7 @@ int main(int argc, char* argv[])
     { "file_picker_cmd", "" },
     { "downloads_dir", "" },
     { "idle_timeout", "29" },
+    { "sni_enabled", "1" },
   };
   const std::string mainConfigPath(Util::GetApplicationDir() + std::string("main.conf"));
   std::shared_ptr<Config> mainConfig = std::make_shared<Config>(mainConfigPath, defaultMainConfig);
@@ -279,6 +284,7 @@ int main(int argc, char* argv[])
   Util::SetFilePickerCmd(mainConfig->Get("file_picker_cmd"));
   Util::SetDownloadsDir(mainConfig->Get("downloads_dir"));
   const bool isCoredumpEnabled = (mainConfig->Get("coredump_enabled") == "1");
+  const bool sniEnabled = (mainConfig->Get("sni_enabled") == "1");
 
   // Set logging verbosity level based on config, if not specified with command line arguments
   if (Log::GetVerboseLevel() == Log::INFO_LEVEL)
@@ -390,6 +396,7 @@ int main(int argc, char* argv[])
                                   cacheEncrypt, cacheIndexEncrypt,
                                   idleTimeout,
                                   foldersExclude,
+                                  sniEnabled,
                                   std::bind(&Ui::ResponseHandler, std::ref(ui), std::placeholders::_1,
                                             std::placeholders::_2),
                                   std::bind(&Ui::ResultHandler, std::ref(ui), std::placeholders::_1,
@@ -439,7 +446,9 @@ int main(int argc, char* argv[])
 
   Util::CleanupStdErrRedirect();
 
-  LOG_INFO("exiting nmail");
+  LOG_INFO("exit");
+
+  Log::Cleanup();
 
   return 0;
 }
@@ -469,10 +478,29 @@ static void ShowHelp()
     "\n"
     "Examples:\n"
     "   nmail -s gmail          setup nmail for a gmail account\n"
+    "   nmail                   running nmail without setup wizard will generate\n"
+    "                           default configuration files in ~/.nmail dir if\n"
+    "                           not present already, these can be manually edited\n"
+    "                           to configure nmail for email service providers not\n"
+    "                           supported by the built-in setup wizard (refer to\n"
+    "                           FILES section on ~/.nmail/main.conf for details)\n"
     "\n"
     "Files:\n"
     "   ~/.nmail/auth.conf      configures custom oauth2 client id and secret\n"
-    "   ~/.nmail/main.conf      configures mail account and general settings\n"
+    "   ~/.nmail/main.conf      configures mail account and general settings, for\n"
+    "                           full nmail functionality the following fields\n"
+    "                           shall be configured:\n"
+    "                           address (ex: example@example.com),\n"
+    "                           drafts (folder name, ex: Drafts),\n"
+    "                           imap_host (ex: imap.example.com),\n"
+    "                           imap_port (ex: 993),\n"
+    "                           inbox (folder name, ex: Inbox),\n"
+    "                           name (ex: Firstname Lastname),\n"
+    "                           sent (folder name, ex: Sent),\n"
+    "                           smtp_host (ex: smtp.example.com),\n"
+    "                           smtp_port (ex: 465 or 587),\n"
+    "                           trash (folder name, ex: Trash),\n"
+    "                           user (ex: example@example.com or example).\n"
     "   ~/.nmail/ui.conf        customizes UI settings\n"
     "   ~/.nmail/secret.conf    stores saved passwords\n"
     "\n"
