@@ -9,6 +9,7 @@
 
 #include <algorithm>
 #include <csignal>
+#include <cstring>
 #include <fstream>
 #include <iomanip>
 #include <map>
@@ -21,11 +22,14 @@
 #include <execinfo.h>
 #endif
 #include <libgen.h>
+#include <netdb.h>
 #include <termios.h>
 #include <unistd.h>
 #include <wordexp.h>
 
 #include <sys/resource.h>
+#include <sys/socket.h>
+#include <sys/types.h>
 
 #ifdef __APPLE__
 #include <libproc.h>
@@ -1386,9 +1390,6 @@ std::map<int, std::string> Util::GetCrashingSignals()
     { SIGSEGV, "SIGSEGV" },
     { SIGSYS, "SIGSYS" },
     { SIGTRAP, "SIGTRAP" },
-#ifdef HAS_THREADS_CRASH_STACKS
-    { SIGUSR1, "SIGUSR1" },
-#endif
   };
   return crashingSignals;
 }
@@ -1413,7 +1414,6 @@ std::map<int, std::string> Util::GetIgnoredSignals()
 {
   static const std::map<int, std::string> ignoredSignals =
   {
-    { SIGINT, "SIGINT" },
     { SIGPIPE, "SIGPIPE" },
   };
   return ignoredSignals;
@@ -1426,7 +1426,7 @@ std::string Util::GetSigName(int p_Signal)
   return (it != signames.end()) ? it->second : std::to_string(p_Signal);
 }
 
-void Util::RegisterSignalHandlers()
+void Util::InitAppSignalHandlers()
 {
   const std::map<int, std::string>& crashingSignals = GetCrashingSignals();
   for (const auto& crashingSignal : crashingSignals)
@@ -1439,10 +1439,7 @@ void Util::RegisterSignalHandlers()
   {
     signal(terminatingSignal.first, SignalTerminateHandler);
   }
-}
 
-void Util::RegisterIgnoredSignalHandlers()
-{
   const std::map<int, std::string>& ignoredSignals = GetIgnoredSignals();
   for (const auto& ignoredSignal : ignoredSignals)
   {
@@ -1450,60 +1447,39 @@ void Util::RegisterIgnoredSignalHandlers()
   }
 }
 
-void Util::RestoreIgnoredSignalHandlers()
+void Util::InitUiSignalHandlers()
 {
-  const std::map<int, std::string>& ignoredSignals = GetIgnoredSignals();
-  for (const auto& ignoredSignal : ignoredSignals)
-  {
-    signal(ignoredSignal.first, SIG_DFL);
-  }
+  signal(SIGINT, SIG_IGN);
 }
 
-static std::mutex s_SignalMutex;
+void Util::CleanupUiSignalHandlers()
+{
+  signal(SIGINT, SIG_DFL);
+}
 
 void Util::SignalCrashHandler(int p_Signal)
 {
-  const std::string& threadLabel = "\nthread " + ThreadRegister::GetName() + "\n";
-  void* callstack[64];
+  char logMsg[64];
+  snprintf(logMsg, sizeof(logMsg), "unexpected termination %d\ncallstack:\n", p_Signal);
+  void* callstack[64] = { 0 };
 #ifdef HAVE_EXECINFO_H
   int size = backtrace(callstack, sizeof(callstack));
 #else
   int size = 0;
 #endif
-  const std::string& callstackStr = BacktraceSymbolsStr(callstack, size);
+  Log::Callstack(callstack, size, logMsg);
 
-  if (p_Signal != SIGUSR1)
-  {
-    {
-      std::lock_guard<std::mutex> lock(s_SignalMutex);
+  // non-signal safe code section
+  CleanupStdErrRedirect();
+  UNUSED(system("reset"));
+  UNUSED(write(STDERR_FILENO, logMsg, strlen(logMsg)));
 
-      const std::string& logMsg = "unexpected termination: " + GetSigName(p_Signal);
-      LOG_ERROR("%s", logMsg.c_str());
-      LOG_DUMP(threadLabel.c_str());
-      LOG_DUMP(callstackStr.c_str());
-
-      CleanupStdErrRedirect();
-      LOG_IF_NONZERO(system("reset"));
-      std::cerr << logMsg << "\n" << callstackStr << "\n";
-    }
-
-#ifdef HAS_THREADS_CRASH_STACKS
-    if (Log::GetTraceEnabled())
-    {
-      ThreadRegister::SignalThreads(SIGUSR1);
-      sleep(1);
-    }
+#ifdef HAVE_EXECINFO_H
+  backtrace_symbols_fd(callstack, size, STDERR_FILENO);
 #endif
 
-    signal(p_Signal, SIG_DFL);
-    kill(getpid(), p_Signal);
-  }
-  else
-  {
-    std::lock_guard<std::mutex> lock(s_SignalMutex);
-    LOG_DUMP(threadLabel.c_str());
-    LOG_DUMP(callstackStr.c_str());
-  }
+  signal(p_Signal, SIG_DFL);
+  kill(getpid(), p_Signal);
 }
 
 void Util::SignalTerminateHandler(int p_Signal)
@@ -1513,44 +1489,6 @@ void Util::SignalTerminateHandler(int p_Signal)
   Ui::SetRunning(false);
 }
 
-std::string Util::BacktraceSymbolsStr(void* p_Callstack[], int p_Size)
-{
-  std::stringstream ss;
-  for (int i = 0; i < p_Size; ++i)
-  {
-    ss << std::left << std::setw(2) << std::setfill(' ') << i << "  ";
-    ss << "0x" << std::hex << std::setw(16) << std::setfill('0') << std::right
-       << (unsigned long long)p_Callstack[i] << "  ";
-
-    Dl_info dlinfo;
-    if (dladdr(p_Callstack[i], &dlinfo) && dlinfo.dli_sname)
-    {
-      if (dlinfo.dli_sname[0] == '_')
-      {
-        int status = -1;
-        char* demangled = NULL;
-        demangled = abi::__cxa_demangle(dlinfo.dli_sname, NULL, 0, &status);
-        if (demangled && (status == 0))
-        {
-          ss << demangled;
-          free(demangled);
-        }
-        else
-        {
-          ss << dlinfo.dli_sname;
-        }
-      }
-      else
-      {
-        ss << dlinfo.dli_sname;
-      }
-    }
-    ss << "\n";
-  }
-
-  return ss.str();
-}
-
 bool Util::IsInteger(const std::string& p_Str)
 {
   return (p_Str.find_first_not_of("0123456789") == std::string::npos);
@@ -2259,3 +2197,96 @@ void Util::InitCoredump()
   }
 #endif
 }
+
+std::string Util::GetCompiler()
+{
+#if defined(__VERSION__)
+#if !defined(__clang__) && defined(__GNUC__)
+  std::string compiler = "GCC " __VERSION__;
+#else
+  std::string compiler = __VERSION__;
+#endif
+#else
+  std::string compiler = "Unknown compiler";
+#endif
+
+#if defined(__linux__)
+#if defined(__GLIBC__) && defined(__GLIBC_MINOR__)
+  std::stringstream sslibc;
+  sslibc << "glibc " << __GLIBC__ << "." << __GLIBC_MINOR__;
+  std::string libc = sslibc.str();
+#else
+  std::string libc = "non-glibc";
+#endif
+#else
+  std::string libc;
+#endif
+
+  return compiler + (!libc.empty() ? " " + libc : "");
+}
+
+std::string Util::GetOsArch()
+{
+  static const std::string os = []()
+  {
+#if defined(__linux__)
+    std::string str = ReadFile("/etc/os-release");
+    std::string prettyName = ExtractString(str, "PRETTY_NAME=\"", "\"");
+    return prettyName.empty() ? "Linux" : prettyName;
+#elif defined(__APPLE__)
+    std::string str = ReadFile("/System/Library/CoreServices/SystemVersion.plist");
+    std::string name = ExtractString(str, "<key>ProductName</key>\n\t<string>", "</string>");
+    std::string ver = ExtractString(str, "<key>ProductVersion</key>\n\t<string>", "</string>");
+    return name + " " + ver;
+#else
+    return "Unknown";
+#endif
+  }();
+
+  static const std::string arch = []()
+  {
+#if defined(__arm__)
+    return "arm";
+#elif defined(__aarch64__)
+    return "arm64";
+#elif defined(__x86_64__) || defined(__amd64__)
+    return "x86_64";
+#elif defined(__i386__)
+    return "i386";
+#else
+    return std::to_string(sizeof(void*) * 8) + "-bit";
+#endif
+  }();
+
+  static const std::string osArch = os + " " + arch;
+  return osArch;
+}
+
+std::string Util::ExtractString(const std::string& p_Str, const std::string& p_Prefix, const std::string& p_Suffix)
+{
+  std::size_t prefixPos = p_Str.find(p_Prefix);
+  if (prefixPos != std::string::npos)
+  {
+    std::size_t suffixPos = p_Str.find(p_Suffix, prefixPos + p_Prefix.size());
+    std::size_t len = (suffixPos != std::string::npos) ? (suffixPos - prefixPos - p_Prefix.size()) : std::string::npos;
+    return p_Str.substr(prefixPos + p_Prefix.size(), len);
+  }
+
+  return "";
+}
+
+bool Util::IsIpAddress(const std::string& p_Str)
+{
+  struct addrinfo addrhints;
+  memset(&addrhints, 0, sizeof(struct addrinfo));
+  addrhints.ai_family = AF_UNSPEC;
+  addrhints.ai_flags = AI_NUMERICHOST;
+  struct addrinfo* addr = nullptr;
+  bool rv = (getaddrinfo(p_Str.c_str(), NULL, &addrhints, &addr) == 0);
+  if (rv && (addr != nullptr))
+  {
+    freeaddrinfo(addr);
+  }
+
+  return rv;
+}
