@@ -20,6 +20,7 @@
 #define KEY_DELETE 127
 
 #define THREAD_REGISTER() ThreadRegister threadRegister(__PRETTY_FUNCTION__)
+#define UNUSED(x) Util::Unused(x)
 
 struct mailimap_date_time;
 
@@ -220,12 +221,11 @@ public:
   static std::string FromOctString(const std::string& p_Str);
   static void HexToRGB(const std::string p_Str, uint32_t& p_R, uint32_t& p_G, uint32_t& p_B);
 
-  static void RegisterSignalHandlers();
-  static void RegisterIgnoredSignalHandlers();
-  static void RestoreIgnoredSignalHandlers();
+  static void InitAppSignalHandlers();
+  static void InitUiSignalHandlers();
+  static void CleanupUiSignalHandlers();
   static void SignalCrashHandler(int p_Signal);
   static void SignalTerminateHandler(int p_Signal);
-  static std::string BacktraceSymbolsStr(void* p_Callstack[], int p_Size);
 
   static bool IsInteger(const std::string& p_Str);
   static long ToInteger(const std::string& p_Str);
@@ -290,6 +290,17 @@ public:
   static void RemoveNonAlphaNumSpace(std::string& p_Str);
   static void InitCoredump();
 
+  static std::string GetCompiler();
+  static std::string GetOsArch();
+  static std::string ExtractString(const std::string& p_Str, const std::string& p_Prefix, const std::string& p_Suffix);
+  static bool IsIpAddress(const std::string& p_Str);
+
+  template<typename T>
+  static inline void Unused(const T& p_Arg)
+  {
+    (void)p_Arg;
+  }
+
 private:
   static std::string m_HtmlToTextConvertCmd;
   static std::string m_TextToHtmlConvertCmd;
